Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(739)

Unified Diff: runtime/vm/bitmap_test.cc

Issue 2572563004: Improve the casing of Stackmap and Stacktrace. (Closed)
Patch Set: Build fixes Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/bitmap.h ('k') | runtime/vm/clustered_snapshot.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/bitmap_test.cc
diff --git a/runtime/vm/bitmap_test.cc b/runtime/vm/bitmap_test.cc
index f3ec1234f8eb6d28e24e9457cf0e2dfcf7a12b65..95fcd68e32711f08d904f299e3f9a148d17f695d 100644
--- a/runtime/vm/bitmap_test.cc
+++ b/runtime/vm/bitmap_test.cc
@@ -36,8 +36,8 @@ TEST_CASE(BitmapBuilder) {
EXPECT_EQ(value, builder1->Get(i));
value = !value;
}
- // Create a Stackmap object from the builder and verify its contents.
- const Stackmap& stackmap1 = Stackmap::Handle(Stackmap::New(0, builder1, 0));
+ // Create a StackMap object from the builder and verify its contents.
+ const StackMap& stackmap1 = StackMap::Handle(StackMap::New(0, builder1, 0));
EXPECT_EQ(1024, stackmap1.Length());
OS::Print("%s\n", stackmap1.ToCString());
value = true;
@@ -62,7 +62,7 @@ TEST_CASE(BitmapBuilder) {
for (int32_t i = 1025; i <= 2048; i++) {
EXPECT(!builder1->Get(i));
}
- const Stackmap& stackmap2 = Stackmap::Handle(Stackmap::New(0, builder1, 0));
+ const StackMap& stackmap2 = StackMap::Handle(StackMap::New(0, builder1, 0));
EXPECT_EQ(2049, stackmap2.Length());
for (int32_t i = 0; i <= 256; i++) {
EXPECT(!stackmap2.IsObject(i));
« no previous file with comments | « runtime/vm/bitmap.h ('k') | runtime/vm/clustered_snapshot.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698